SystemOrganization addCategory: #'SeasideOverflow-Model'!
SystemOrganization addCategory: #'SeasideOverflow-Test'!
SystemOrganization addCategory: #'SeasideOverflow-View'!

TestCase subclass: #AnswerTest
	instanceVariableNames: 'anAnswer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Test'!

!AnswerTest class methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:09'!
testBy
	| anAnswer |
	anAnswer := Answer by: 'Fred Hsu'.
	self assert: (anAnswer user) = 'Fred Hsu'.
	self assert: (anAnswer votes) = 0.! !

!AnswerTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:23'!
setUp
	| user answerText |
	super setUp.
	user := 'Fred Hsu'.
	answerText := '42'.
	anAnswer := Answer by: user with: answerText.! !

!AnswerTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:22'!
testByWith
	| ans user answerText|
	user := 'Fred Hsu'.
	answerText := 'This is my answer.'.
	ans := Answer by: user with: answerText.
	self assert: (ans user) = user.
	self assert: (ans votes) = 0.
	self assert: (ans text) = answerText.! !

!AnswerTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:17'!
testUpDownVote
	anAnswer upVote.
	self assert: anAnswer votes = 1.
	anAnswer upVote.
	self assert: anAnswer votes = 2.
	anAnswer downVote.
	self assert: anAnswer votes = 1.
	anAnswer downVote.
	self assert: anAnswer votes = 0.
	anAnswer downVote.
	self assert: anAnswer votes = -1.
! !

TestCase subclass: #QuestionListTest
	instanceVariableNames: 'questions questionList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Test'!

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 21:52'!
setUp
	| q1 q2 q3 q4 q5 |
	questionList := QuestionList new.
	q1 := (Question by: 'Fred Hsu' with: 'What do you want?').
	q1 title: 'First question'.
	q1 addTag: 'tag1'.
	q1 upVote; upVote; upVote.
	q1 addAnswer: (Answer by: 'Someone' with: 'nothing').
	q1 addAnswer: (Answer by: 'Someone' with: 'something').
	q2 := (Question by: 'Param Singh' with: 'Where?').
	q2 title: 'Second question'.
	q2 addTag: 'tag2'.
	q2 upVote; upVote.
	q3 := (Question by: 'Anonymous' with: 'How?').
	q3 title: 'Third Question'.
	q3 addTag: 'tag1'.
	q3 addTag: 'tag3'.
	q3 addTag: 'you'.
	q3 addTag: 'how'.
	q3 addAnswer: (Answer by: 'Someone' with: 'nothing').
	q3 addAnswer: (Answer by: 'Someone' with: 'something').
	q3 addAnswer: (Answer by: 'Someone' with: 'anything').
	q3 addAnswer: (Answer by: 'Someone' with: 'more').
	q3 upVote.
	q4 := (Question by: 'Foo' with: 'Why?').
	q5 := (Question by: 'Foo' with: 'What?').
	questionList add: q1.
	questionList add: q2.
	questionList add: q3.
	questionList add: q4.
	questionList add: q5.! !

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 22:07'!
testAdd
	questionList add: (Question by: 'User1' with: 'How can I?')! !

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:33'!
testRemove
! !

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 21:53'!
testSearch
	| searchResults |
	"Searching titles"
	searchResults := questionList searchFor: 'title'.
	self assert: (searchResults size) = 2.
	"Also check on various case sensitivies"
	searchResults := questionList searchFor: 'question'.
	self assert: (searchResults size) = 3.
	searchResults := questionList searchFor: 'Question'.
	self assert: (searchResults size) = 3.
	searchResults := questionList searchFor: 'first'.
	self assert: (searchResults size) = 1.
	searchResults := questionList searchFor: 'fifth'.
	self assert: (searchResults size) = 0.
	
	"Searching question bodies"
	searchResults := questionList searchFor: 'what'.
	self assert: (searchResults size) = 2.
	searchResults := questionList searchFor: 'where'.
	self assert: (searchResults size) = 1.
	
	"Searching tags"
	searchResults := questionList searchFor: 'tag1'.
	self assert: (searchResults size) = 2.
	searchResults := questionList searchFor: 'tag2'.
	self assert: (searchResults size) = 1.
	searchResults := questionList searchFor: 'tag4'.
	self assert: (searchResults size) = 0.
	
	"Testing for duplicates"
	searchResults := questionList searchFor: 'how'.
	self assert: (searchResults size) = 1.
	searchResults := questionList searchFor: 'you'.
	self assert: (searchResults size) = 2.
! !

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/16/2012 22:16'!
testSortByAnswers
	questionList sortByAnswers.
	self assert: (questionList questions at: 2) text = 'What do you want?'.
	self assert: (questionList questions at: 1) text = 'How?'.
	
	! !

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/16/2012 22:04'!
testSortByDate
	! !

!QuestionListTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/16/2012 22:17'!
testSortByVotes
	questionList sortByVotes.
	self assert: (questionList questions at: 1) text = 'What do you want?'.
	self assert: (questionList questions at: 2) text = 'Where?'.
	! !

TestCase subclass: #QuestionTest
	instanceVariableNames: 'question'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Test'!

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:08'!
setUp
	| user questionText  |
	super setUp.
	user := 'Fred Hsu'.
	questionText := 'What is the meaning to life, the universe, and everything?'.
	question := Question by: user with: questionText.! !

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:36'!
testAddAnswer
	| answer1 answer2 answer3 |
	answer1 := Answer by: 'user1' with: 'answerText1'.
	answer2 := Answer by: 'user2' with: 'answerText2'.
	answer3 := Answer by: 'user3' with: 'answerText3'.
	question addAnswer: answer1.
	self assert: (question answers includes: answer1).
	question addAnswer: answer2.
	self assert: (question answers includes: answer2).
	question addAnswer: answer3.	
	self assert: (question answers includes: answer3).
! !

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:31'!
testAddRemoveTags
	question addTag: 'foo'.
	self assert: (question hasTag: 'foo').
	question removeTag: 'foo'.
	self assert: ((question hasTag: 'foo') not).! !

!QuestionTest methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:13'!
testIncrementViews
	self assert: question views = 0.
	question incrementViews.
	self assert: question views = 1.
	question incrementViews.
	self assert: question views = 2.! !

TestCase subclass: #UserListTest
	instanceVariableNames: 'users userList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Test'!

!UserListTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:44'!
setUp
	userList := UserList new.
	userList add: (User new addUser: 'user1' passcode: 'Passcode1' email: 'user1@so.com')! !

!UserListTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:44'!
testAdd
	|user|
	userList add: (User new addUser: 'user2' passcode: 'Passcode2' email: 'user2@so.com').
	user := userList user: 'user1'.
	self assert: (user password = 'Passcode1').
	user := userList user: 'user2'.
	self assert: (user password = 'Passcode2').! !

!UserListTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/16/2012 00:50'!
testRemove
	|user user2|
	user := userList user: 'user1'.
	userList remove: user.
	user2 := userList user: 'user1'.
	self assert: (user ~= user2).! !

TestCase subclass: #UserTest
	instanceVariableNames: 'user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Test'!

!UserTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:43'!
setUp
	super setUp.
	user := User new addUser: 'testUser1' passcode: 'testpasscode1' email: 'testUser1@so.com'.
	! !

!UserTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/16/2012 21:48'!
testActive
	self assert: (user isActive = 'Y').
	user makeInactive.
	self assert: (user isActive = 'N').
	user makeActive.
	self assert: (user isActive = 'Y').! !

!UserTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:51'!
testEmailId
	|email|
	email := user anEmailId.
	self assert: (email = 'testUser1@so.com').
	user anEmailId: 'user11@so.com'.
	email := user anEmailId.
	self assert: (email = 'user11@so.com').! !

!UserTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/16/2012 21:41'!
testLogin
	user logIn.
	self assert: (user isLoggedIn = 'Y').
	user logout.
	self assert: (user isLoggedIn = 'N').! !

!UserTest methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/16/2012 21:44'!
testProfileType
	self assert: (user profileType = 'USER').
	user makeAdmin.
	self assert: (user profileType = 'ADMIN').! !

WAFileLibrary subclass: #MyFileLibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-View'!

!MyFileLibrary methodsFor: 'uploaded' stamp: 'FredHsu 7/18/2012 12:01'!
mainCss
	^ 'h1 { text-align: center; }
.counter { float: left; text-align: center; margin: 0 3px 0 0; padding: 5px}
.sort-element { float: left; text-align: center; margin: 0 3px 0 0; padding: 5px}
.title { font-weight: bold; font-size: 140%}
div { display: block }
.question-summary { float: left; width: 730px; clear: left }
.sorting { float: left; width: 730px; clear: left }
'! !

WAComponent subclass: #AddAnswerView
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-View'!

!AddAnswerView commentStamp: 'FredHsu 7/9/2012 21:27' prior: 0!
AddAnswerView is a view used for adding answers to a question.  It is called from QuestionView.

Instance Variables:
	model	<DisplayText | DisplayText class | Entry | HostSystemMenusMenuItem | JQAjax | JQButton | JQueryInstance | JoinSide | MCPatchBrowser | MCSnapshotBrowser | MessageDialogWindow | NewTextMorph | OBAnnotationPanel | OBCompletionDialog | OBDefinition | OBFakeText | OBNode | OBTextDefinition class | PopupChoiceDialogWindowWithMessage | SUSmallBoxTest | SUTooltipTest | WAAnchorTag | WAFormInputTag | WARenderer | ZnEntity class>!

!AddAnswerView methodsFor: 'accessing' stamp: 'FredHsu 7/5/2012 11:20'!
model
	^ model! !

!AddAnswerView methodsFor: 'accessing' stamp: 'FredHsu 7/5/2012 11:20'!
model: anObject
	model := anObject! !

!AddAnswerView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/5/2012 11:18'!
renderContentOn: html
	html heading: 'Add Answer'.
	   html form: [
        html text: 'Answer'; break.
        html textInput
            callback: [ :value | self model text: value ].
  html submitButton
            callback: [ self answer: self model ];
            text: 'Save'.
        html cancelButton
            callback: [ self answer: nil ];
            text: 'Cancel' ]! !

!AddAnswerView methodsFor: 'accessing' stamp: 'FredHsu 7/18/2012 12:04'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: (MyFileLibrary urlOf: #mainCss)! !

WAComponent subclass: #AddQuestionView
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-View'!

!AddQuestionView commentStamp: 'FredHsu 7/9/2012 21:27' prior: 0!
AddQuestionView is a form to add questions, it is called from QuestionView

Instance Variables:
	model	<Question>!

!AddQuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:05'!
model
	^ model! !

!AddQuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:05'!
model: anObject
	model := anObject! !

!AddQuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/8/2012 20:50'!
renderContentOn: html
	html heading: 'Add Question'.
	   html form: [
        html text: 'Title:'; break.
        html textInput
            value: self model title;
            callback: [ :value | self model title: value ].
	html break.
	html text: 'Question'; break.
	html textArea
		rows: 10;
		columns: 40;
		callback: [ :value | self model text: value ].
	html break.
	html text: 'Tags'; break.
	html textInput
		callback: [ :value | (value subStrings: ' ,') do: [:each | self model addTag: each]].
  html submitButton
            callback: [ self answer: self model ];
            text: 'Save'.
        html cancelButton
            callback: [ self answer: nil ];
            text: 'Cancel' ]
! !

!AddQuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/18/2012 12:04'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: (MyFileLibrary urlOf: #mainCss)! !

WAComponent subclass: #LoginUserView
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-View'!

!LoginUserView class methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/18/2012 23:38'!
canBeRoot
	^ true ! !

!LoginUserView class methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/18/2012 23:33'!
initialize 
	"LoginUserView initialize"
	WAAdmin register: self asApplicationAt: 'login'.! !

!LoginUserView methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 23:12'!
login: aUserName password: aPassword
	|user|
	user := UserList user: aUserName.
	user password = aPassword ifTrue:[user logIn].! !

!LoginUserView methodsFor: 'accessing' stamp: 'ParamvirSingh 7/17/2012 23:08'!
model
	^model! !

!LoginUserView methodsFor: 'accessing' stamp: 'ParamvirSingh 7/17/2012 23:08'!
model: aObject
	model := aObject.! !

!LoginUserView methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/18/2012 23:44'!
renderContentOn: html
	html heading: 'Seaside Overflow User Login'.
  	html form: [
        html text: 'User Id : '.
        html textInput
            callback: [ nil ].
	   html break. 
	  html text: 'Password : '.
        html textInput
            callback: [ nil ].
	html break. 	
	html submitButton
	      callback: [ self login: 'user' password: 'pass' ];
            text: 'Login'.
 ].
	! !

WAComponent subclass: #QuestionListView
	instanceVariableNames: 'model search'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-View'!

!QuestionListView commentStamp: 'FredHsu 7/9/2012 21:27' prior: 0!
QuestionListView is currently the main page, and lists the questions that have been asked.

Instance Variables:
	model	<QuestionList>!

!QuestionListView class methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 22:14'!
initialize 
	"QuestionListView initialize"
	WAAdmin register: self asApplicationAt: 'so'.! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:34'!
addQuestion
	| newQuestion |
	newQuestion := self call: (AddQuestionView new model: (Question by: 'testuser' with: 'testquestion')).
	self model add: newQuestion
	! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 22:17'!
children
	^Array with: search.
	! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:33'!
initialize 
	super initialize.
	model := QuestionList new.
	model add: ((Question by: 'me' with: 'text') title: 'new title')! !

!QuestionListView methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:33'!
model
	^ model! !

!QuestionListView methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:33'!
model: anObject
	model := anObject! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 22:26'!
renderContentOn: html
	html heading: 'Seaside Overflow'.
	html anchor
		callback: [ self addQuestion ];
		with: 'Add Question'.
	html break.
	html render: search.
  	html form: [
        html text: 'Search'; break.
        html textInput
            callback: [:value | self searchFor: value ].
	html submitButton
	      callback: [ self ];
            text: 'Go'.
 ].
	html div
		class: 'sorting';
		with: [
			html div class:'sort-element'; with: [
				html anchor
				callback: [ model sortByVotes ];
				with: 'Sort by Votes'..].
			html div class:'sort-element'; with: [
				html anchor
				callback: [ model sortByAnswers];
				with: 'Sort by Answers'..].
			html div class:'sort-element'; with: [
				html anchor
				callback: [ model sortByDate];
				with: 'Sort by Date'..].
			].

	self renderQuestionsOn: html.! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/6/2012 20:03'!
renderQuestion: aQuestion on: html
"TODO: Refacor this to use an interator, will need to make a dictionary or objects of counters in model"
	html div
		class: 'question-summary';
		with: [
		html div
			class: 'counter';
			with: [ 
				html div: aQuestion votes.
				html div: 'Votes'].
		html div
			class: 'counter';
			with: [ 
				html div: aQuestion answers size.
				html div: 'Answers'].
		html div
			class: 'counter';
			with: [ 
				html div: aQuestion views.
				html div: 'Views'].
		html div
			class: 'summary';
			with: [ html anchor
					callback: [self viewQuestion: aQuestion];
					class: 'title';
					with: aQuestion title.
				].
		aQuestion tags do: [:each |
			html text: each.
			html space].
		html text: aQuestion date.
		html space.
		html text: aQuestion user. 
		html break.]! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:33'!
renderQuestionsOn: html
	model questions do: [:each | self renderQuestion: each on: html]! !

!QuestionListView methodsFor: 'accessing' stamp: 'FredHsu 7/18/2012 22:26'!
searchFor: aString
	self model questions: (self model searchFor: aString).! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 12:04'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: (MyFileLibrary urlOf: #mainCss)! !

!QuestionListView methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:24'!
viewQuestion: aQuestion
	self call: (QuestionView new model: aQuestion)
	! !

WAComponent subclass: #QuestionView
	instanceVariableNames: 'model'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-View'!

!QuestionView commentStamp: 'FredHsu 7/9/2012 21:28' prior: 0!
QuestionView is the detailed question view that the user sees when the click on a question title from QuestionListView.

Instance Variables:
	model	<Question>!

!QuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/5/2012 11:20'!
addAnswer
	| newAnswer |
	newAnswer := self call: (AddAnswerView new model: (Answer by: 'testuser' with: 'testanswer')).
	self model addAnswer: newAnswer! !

!QuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:20'!
model
	^ model! !

!QuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:20'!
model: anObject
	model := anObject! !

!QuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/9/2012 21:24'!
renderContentOn: html
	html heading: model title.
	html horizontalRule.
	html anchor
		callback: [ model upVote ];
		with: 'Up'.
	html break.
	html text: model votes.
	html break.
	html text: model text.
	html break.
	html anchor
		callback: [ model downVote ];
		with: 'Down'.
	html break.
	html heading: 'Answers'.
	model answers do: [ :each |
		html anchor
		callback: [ each upVote ];
		with: 'Up'.
	html break.
	html text: each votes.
	html break.
	html text: each text.
	html break.
	html anchor
		callback: [ each downVote ];
		with: 'Down'.
		html horizontalRule].
	html anchor
		callback: [ self addAnswer ];
		with: 'Add Answer'.
	html space.
	html anchor
		callback: [ self answer: nil ];
		with: 'Return to Questions'.! !

!QuestionView methodsFor: 'accessing' stamp: 'FredHsu 7/18/2012 12:03'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: (MyFileLibrary urlOf: #mainCss)! !

Object subclass: #Entry
	instanceVariableNames: 'text user votes date'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Model'!

!Entry commentStamp: 'FredHsu 7/3/2012 23:15' prior: 0!
Entry a superclass for questions and answers

Instance Variables:
	text	<ProtoObject | PseudoContext>
	user	<ProtoObject | PseudoContext>
	votes	<Number>
	date	<Date>!

Entry subclass: #Answer
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Model'!

!Answer commentStamp: 'FredHsu 7/3/2012 21:41' prior: 0!
An answer to a question!

!Entry class methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:20'!
by: aUser with: someText
	^self new by: aUser with: someText.! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:19'!
by: aUser with: someText
	user := aUser.
	date := Date today.
	text := someText.
	votes := 0.
	! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:10'!
date
	^date! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:11'!
downVote
	votes := votes - 1! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:23'!
text
	^text! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/5/2012 11:21'!
text: aString
	text := aString! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:10'!
upVote
	votes := votes + 1! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:09'!
user
	^user! !

!Entry methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 22:09'!
votes
	^votes! !

Entry subclass: #Question
	instanceVariableNames: 'answers views tags title'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Model'!

!Question commentStamp: 'FredHsu 7/3/2012 21:41' prior: 0!
A question posed by a user!

!Question class methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:13'!
by: aUser
	^self new by: aUser! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:32'!
addAnswer: anAnswer
	answers add: anAnswer.! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:25'!
addTag: aTag
	tags add: aTag.! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:23'!
answers
	^answers! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:14'!
by: aUser
	self by: aUser with: ''! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 23:15'!
by: aUser with: someText
	super by: aUser with: someText.
	answers := OrderedCollection new.
	views := 0.
	tags := Set new.
	title := 'new title'! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:28'!
hasTag: aTag
	^tags includes: aTag.! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:24'!
incrementViews 
	views := views + 1.! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:29'!
removeTag: aTag
	tags remove: aTag.! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:23'!
tags
	^tags! !

!Question methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:07'!
title
	^ title! !

!Question methodsFor: 'accessing' stamp: 'FredHsu 7/4/2012 23:07'!
title: anObject
	title := anObject! !

!Question methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/3/2012 23:23'!
views
	^views! !

Object subclass: #QuestionList
	instanceVariableNames: 'questions'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Model'!

!QuestionList commentStamp: 'FredHsu 7/3/2012 23:15' prior: 0!
QuestionListing is a list of questions on the system

	questions	<ProtoObject | PseudoContext>!

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 22:03'!
add: aQuestion
	questions add: aQuestion! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 22:05'!
initialize
	super initialize.
	questions := SortedCollection sortBlock: [:q1 :q2 | q1 date <= q2 date].! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 22:08'!
questions
	^questions! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 22:02'!
questions: aCollection
	questions := questions asSortedCollection: [:q1 :q2 | q1 answers size >= q2 answers size]..! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/4/2012 22:04'!
remove: aQuestion
	questions remove: aQuestion! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/18/2012 21:54'!
searchFor: aString
	| result searchString |
	searchString := '*', aString, '*'.
	result := questions select: [:each | searchString match: each title].
	result addAll: (questions select: [:each | searchString match: each text]).
	result addAll: (questions select: [:each | each hasTag: aString]).
	
	^result asSet
! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/16/2012 22:14'!
sortByAnswers
	questions sortBlock: [:q1 :q2 | q1 answers size >= q2 answers size].! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/16/2012 21:59'!
sortByDate
	questions sortBlock: [:q1 :q2 | q1 date <= q2 date].! !

!QuestionList methodsFor: 'as yet unclassified' stamp: 'FredHsu 7/16/2012 22:11'!
sortByVotes
	questions sortBlock: [:q1 :q2 | q1 votes >= q2 votes].! !

Object subclass: #User
	instanceVariableNames: 'userName password profileType isActive memberSince dateUpdated isLoggedIn anEmailId'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Model'!

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:38'!
addUser: aUserName passcode: aPassword email: anEmail
	userName := aUserName.
	password := aPassword.
	dateUpdated := Date new.
	memberSince := Date new.
	isActive := 'Y'.
	isLoggedIn := 'N'.
	profileType := 'USER'.
	anEmailId := anEmail.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:40'!
anEmailId
	^anEmailId! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 22:48'!
anEmailId: emailId
	^anEmailId := emailId.
! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:20'!
dateUpdated
	^dateUpdated! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:24'!
initialize
	userName := ''.
	password := ''.
	profileType := 'USER'.
	isActive := 'N'.
	memberSince := Date new.
	dateUpdated := Date new.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:19'!
isActive
	^isActive! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:27'!
isLoggedIn
	^isLoggedIn! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/10/2012 22:03'!
logIn
	isLoggedIn := 'Y'.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/10/2012 22:03'!
logout
	isLoggedIn := 'N'.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/16/2012 21:53'!
makeActive
	isActive := 'Y'.
	dateUpdated := Date new.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:47'!
makeAdmin
	self profileType: 'ADMIN'.
	dateUpdated := Date new.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:57'!
makeInactive
	isActive := 'N'.
	dateUpdated := Date new.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:20'!
memberSince
	^memberSince! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:18'!
password
	^password! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:19'!
profileType
	^profileType! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:44'!
profileType: aType
	profileType := aType.! !

!User methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:18'!
userName
	^userName! !

Object subclass: #UserList
	instanceVariableNames: 'users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideOverflow-Model'!

!UserList methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:54'!
add: aUser
	users add: aUser.! !

!UserList methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/17/2012 23:16'!
initialize
	super initialize.
	users := OrderedCollection new.
	self add: (User new addUser: 'user1' passcode: 'Passcode1' email: 'user1@so.com').
	self user: 'user1' makeAdmin.! !

!UserList methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/10/2012 22:04'!
login: aUserName password: aPassword
	|user|
	user := self user: aUserName.
	user password = aPassword ifTrue:[user logIn].! !

!UserList methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:55'!
remove: aUser
	users remove: aUser! !

!UserList methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/10/2012 21:33'!
user: aUserName
	self users do:[:each| each userName = aUserName ifTrue:[^each]].! !

!UserList methodsFor: 'as yet unclassified' stamp: 'ParamvirSingh 7/5/2012 23:55'!
users
	^users! !
LoginUserView initialize!
QuestionListView initialize!
